package com.muyu.clw.common.many.datasource;

import com.alibaba.druid.pool.DruidDataSource;
import com.muyu.clw.common.many.datasource.domain.model.DataSourceInfo;
import com.muyu.clw.common.many.remote.RemoteEnterpriseService;
import com.muyu.clw.common.saas.domain.model.EntInfo;
import com.muyu.clw.common.many.datasource.factory.DruidDataSourceFactory;
import com.muyu.clw.common.many.datasource.role.DynamicDataSource;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.SpringUtils;
import com.muyu.domain.Enterprise;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 多数据源
 *
 * @ClassName ManyDataSource
 * @Author AnNan.Wang
 * @Date 2024/6/4 14:10
 */

@Log4j2
@Component
public class ManyDataSource {
    @Autowired
    private RemoteEnterpriseService remoteEnterpriseService;
    public  List<EntInfo> dataSourceInfoList() {

        Result<List<Enterprise>> enterprise = remoteEnterpriseService.enterpriseAllList();

        List<Enterprise> enterpriseList = enterprise.getData();


        List<EntInfo> list = new ArrayList<>();

        for (Enterprise enterprise1 : enterpriseList) {
            list.add(
                    EntInfo.builder()
                            .entCode("ent_"+enterprise1.getContactPhone().substring(enterprise1.getContactPhone().length()-4))
                            .ip("123.56.102.11")
                            .port((int) (3306+enterprise1.getId()))
                            .build()
            );
        }
        return list;
    }

    @Bean
    @Primary
    public DynamicDataSource dynamicDataSource(DruidDataSourceFactory druidDataSourceFactory) {

        Map<Object, Object> dataSourceMap = new HashMap<>();
        dataSourceInfoList()
                .stream()
                .map(entInfo -> DataSourceInfo.hostAndPortBuild(entInfo.getEntCode(),entInfo.getIp(),entInfo.getPort()))
                .forEach(dataSourceInfo -> {
                    dataSourceMap.put(dataSourceInfo.getKey(), druidDataSourceFactory.create(dataSourceInfo));
                });

        //设置动态数据源
        DynamicDataSource dynamicDataSource = new DynamicDataSource();
//        dynamicDataSource.setDefaultTargetDataSource(masterDataSource());
        dynamicDataSource.setTargetDataSources(dataSourceMap);
        //将数据源信息备份在defineTargetDataSources中
        dynamicDataSource.setDefineTargetDataSources(dataSourceMap);
        return dynamicDataSource;
    }
}
