package com.muyu.clw.common.many.datasource.factory;

import com.alibaba.druid.pool.DruidDataSource;
import com.muyu.clw.common.many.datasource.domain.model.DataSourceInfo;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Component;

import java.sql.SQLException;

/**
 * Druid工厂
 *
 * @ClassName DruidDataSourceFactory
 * @Author AnNan.Wang
 * @Date 2024/6/4 14:14
 */

@Log4j2
@Component
public class DruidDataSourceFactory {
    /**
     * @Description: 根据传递的数据源信息测试数据库连接
     * @Author AnNan.Wang
     */
    public DruidDataSource create(DataSourceInfo dataSourceInfo) {
        DruidDataSource druidDataSource = new DruidDataSource();
        druidDataSource.setUrl(dataSourceInfo.getUrl());
        druidDataSource.setUsername(dataSourceInfo.getUserName());
        druidDataSource.setPassword(dataSourceInfo.getPassword());
        druidDataSource.setBreakAfterAcquireFailure(true);
        druidDataSource.setConnectionErrorRetryAttempts(0);
        druidDataSource.setMaxActive(20); // 设置最大活动连接数为 20
        log.info( "{}->数据源连接成功", dataSourceInfo.getKey());
        return druidDataSource;
    }
}
