package com.muyu.authentication.controller;

import com.muyu.authentication.service.IAddServiceService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.AddService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 增值Controller
 *
 * @author wan
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/AddService")
public class AddServiceController extends BaseController
{
    @Autowired
    private IAddServiceService addServiceService;

    /**
     * 查询增值列表
     */
    @RequiresPermissions("authentication:AddService:list")
    @GetMapping("/list")
    public Result<TableDataInfo<AddService>> list(AddService addService)
    {
        startPage();
        List<AddService> list = addServiceService.selectAddServiceList(addService);
        return getDataTable(list);
    }

    /**
     * 导出增值列表
     */
    @RequiresPermissions("authentication:AddService:export")
    @Log(title = "增值", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AddService addService)
    {
        List<AddService> list = addServiceService.selectAddServiceList(addService);
        ExcelUtil<AddService> util = new ExcelUtil<AddService>(AddService.class);
        util.exportExcel(response, list, "增值数据");
    }

    /**
     * 获取增值详细信息
     */
    @RequiresPermissions("authentication:AddService:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(addServiceService.selectAddServiceById(id));
    }

    /**
     * 新增增值
     */
    @RequiresPermissions("authentication:AddService:add")
    @Log(title = "增值", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody AddService addService)
    {
        return toAjax(addServiceService.insertAddService(addService));
    }

    /**
     * 修改增值
     */
    @RequiresPermissions("authentication:AddService:edit")
    @Log(title = "增值", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody AddService addService)
    {
        return toAjax(addServiceService.updateAddService(addService));
    }

    /**
     * 删除增值
     */
    @RequiresPermissions("authentication:AddService:remove")
    @Log(title = "增值", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(addServiceService.deleteAddServiceByIds(ids));
    }
}
