package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.IEnterpriseService;
import com.muyu.domain.vo.EnterpriseReq;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.Enterprise;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 企业Controller
 *
 * @author wan
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/enterprise")
public class EnterpriseController extends BaseController
{

    @Autowired
    private IEnterpriseService enterpriseService;

    /**
     * 查询企业列表
     */
    @RequiresPermissions("authentication:enterprise:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Enterprise>> list(Enterprise enterprise)
    {
        startPage();
        List<Enterprise> list = enterpriseService.selectEnterpriseList(enterprise);
        return getDataTable(list);
    }

    /**
     * 导出企业列表
     */
    @RequiresPermissions("authentication:enterprise:export")
    @Log(title = "企业", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Enterprise enterprise)
    {
        List<Enterprise> list = enterpriseService.selectEnterpriseList(enterprise);
        ExcelUtil<Enterprise> util = new ExcelUtil<Enterprise>(Enterprise.class);
        util.exportExcel(response, list, "企业数据");
    }

    /**
     * 获取企业详细信息
     */
    @RequiresPermissions("authentication:enterprise:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseService.selectEnterpriseById(id));
    }

    /**
     * 新增企业
     */
    @RequiresPermissions("authentication:enterprise:add")
    @Log(title = "企业", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Enterprise enterprise)
    {
        return toAjax(enterpriseService.insertEnterprise(enterprise));
    }

    /**
     * 修改企业
     */
    @RequiresPermissions("authentication:enterprise:edit")
    @Log(title = "企业", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Enterprise enterprise)
    {
        return toAjax(enterpriseService.updateEnterprise(enterprise));
    }

    /**
     * 删除企业
     */
    @RequiresPermissions("authentication:enterprise:remove")
    @Log(title = "企业", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseService.deleteEnterpriseByIds(ids));
    }

    @PostMapping("/enterpriseList")
    public Result<Enterprise> enterpriseList(@RequestBody EnterpriseReq enterpriseReq){
        return Result.success(
                enterpriseService.enterpriseList(enterpriseReq)
        );
    }

    @PostMapping("/enterpriseUpdate")
    public Result<String> enterpriseUpdate(@RequestBody Enterprise enterprise){
        return Result.success(
                enterpriseService.enterpriseUpdate(enterprise)
        );
    }

    @PostMapping("/enterpriseUpdateId")
    public Result<String> enterpriseUpdateId(@RequestParam Long id){
        return Result.success(
                enterpriseService.enterpriseUpdateId(id)
        );
    }

    @GetMapping("/enterpriseAllList")
    public Result<List<Enterprise>> enterprise(){
        return Result.success(
                enterpriseService.list()
        );
    }
}
