package com.muyu.authentication.controller;

import com.muyu.authentication.service.IPayForService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.PayFor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 支付Controller
 *
 * @author wan
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/for")
public class PayForController extends BaseController
{
    @Autowired
    private IPayForService payForService;

    /**
     * 查询支付列表
     */
    @RequiresPermissions("authentication:for:list")
    @GetMapping("/list")
    public Result<TableDataInfo<PayFor>> list(PayFor payFor)
    {
        startPage();
        List<PayFor> list = payForService.selectPayForList(payFor);
        return getDataTable(list);
    }

    /**
     * 导出支付列表
     */
    @RequiresPermissions("authentication:for:export")
    @Log(title = "支付", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PayFor payFor)
    {
        List<PayFor> list = payForService.selectPayForList(payFor);
        ExcelUtil<PayFor> util = new ExcelUtil<PayFor>(PayFor.class);
        util.exportExcel(response, list, "支付数据");
    }

    /**
     * 获取支付详细信息
     */
    @RequiresPermissions("authentication:for:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(payForService.selectPayForById(id));
    }

    /**
     * 新增支付
     */
    @RequiresPermissions("authentication:for:add")
    @Log(title = "支付", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody PayFor payFor)
    {
        return toAjax(payForService.insertPayFor(payFor));
    }

    /**
     * 修改支付
     */
    @RequiresPermissions("authentication:for:edit")
    @Log(title = "支付", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody PayFor payFor)
    {
        return toAjax(payForService.updatePayFor(payFor));
    }

    /**
     * 删除支付
     */
    @RequiresPermissions("authentication:for:remove")
    @Log(title = "支付", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(payForService.deletePayForByIds(ids));
    }
}
