package com.muyu.authentication.controller;

import com.muyu.authentication.service.IVehicleService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.many.domain.Vehicle;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 车辆Controller
 *
 * @author wan
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/vehicle")
public class VehicleController extends BaseController
{
    @Autowired
    private IVehicleService vehicleService;

    /**
     * 查询车辆列表
     */
    @GetMapping("/list")
    public Result<TableDataInfo<Vehicle>> list(Vehicle vehicle,@RequestHeader("ent_code") String entCode)
    {
        startPage();
        List<Vehicle> list = vehicleService.selectVehicleList(vehicle, entCode);
        return getDataTable(list);
    }

    /**
     * 导出车辆列表
     */
    @Log(title = "车辆", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Vehicle vehicle,@RequestHeader("ent_code") String entCode)
    {
        List<Vehicle> list = vehicleService.selectVehicleList(vehicle, entCode);
        ExcelUtil<Vehicle> util = new ExcelUtil<Vehicle>(Vehicle.class);
        util.exportExcel(response, list, "车辆数据");
    }

    /**
     * 获取车辆详细信息
     */
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id,@RequestHeader("ent_code") String entCode)
    {
        return success(vehicleService.selectVehicleById(id,entCode));
    }

    /**
     * 新增车辆
     */
    @Log(title = "车辆", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Vehicle vehicle,@RequestHeader("ent_code") String entCode)
    {
        return toAjax(vehicleService.insertVehicle(vehicle,entCode));
    }

    /**
     * 修改车辆
     */
    @Log(title = "车辆", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Vehicle vehicle,@RequestHeader("ent_code") String entCode)
    {
        return toAjax(vehicleService.updateVehicle(vehicle,entCode));
    }

    /**
     * 删除车辆
     */
    @Log(title = "车辆", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids,@RequestHeader("ent_code") String entCode)
    {
        return toAjax(vehicleService.deleteVehicleByIds(ids,entCode));
    }
}
