package com.muyu.authentication.service.impl;

import com.muyu.authentication.mapper.FenceMapper;
import com.muyu.authentication.service.IFenceService;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.many.domain.Fence;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 电子围栏Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
public class FenceServiceImpl implements IFenceService
{
    @Autowired
    private FenceMapper fenceMapper;

    /**
     * 查询电子围栏
     *
     * @param id 电子围栏主键
     * @return 电子围栏
     */
    @Override
    public Fence selectFenceById(Long id)
    {
        return fenceMapper.selectFenceById(id);
    }

    /**
     * 查询电子围栏列表
     *
     * @param fence 电子围栏
     * @return 电子围栏
     */
    @Override
    public List<Fence> selectFenceList(Fence fence)
    {
        return fenceMapper.selectFenceList(fence);
    }

    /**
     * 新增电子围栏
     *
     * @param fence 电子围栏
     * @return 结果
     */
    @Override
    public int insertFence(Fence fence)
    {
        fence.setCreateTime(DateUtils.getNowDate());
        return fenceMapper.insertFence(fence);
    }

    /**
     * 修改电子围栏
     *
     * @param fence 电子围栏
     * @return 结果
     */
    @Override
    public int updateFence(Fence fence)
    {
        fence.setUpdateTime(DateUtils.getNowDate());
        return fenceMapper.updateFence(fence);
    }

    /**
     * 批量删除电子围栏
     *
     * @param ids 需要删除的电子围栏主键
     * @return 结果
     */
    @Override
    public int deleteFenceByIds(Long[] ids)
    {
        return fenceMapper.deleteFenceByIds(ids);
    }

    /**
     * 删除电子围栏信息
     *
     * @param id 电子围栏主键
     * @return 结果
     */
    @Override
    public int deleteFenceById(Long id)
    {
        return fenceMapper.deleteFenceById(id);
    }
}
