package com.muyu.authentication.service.impl;

import com.muyu.authentication.mapper.VehicleMapper;
import com.muyu.authentication.service.IVehicleService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.many.domain.Vehicle;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.UUID;

/**
 * 车辆Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
public class VehicleServiceImpl implements IVehicleService
{
    @Autowired
    private VehicleMapper vehicleMapper;

    /**
     * 查询车辆
     *
     * @param id 车辆主键
     * @return 车辆
     */
    @Override
    public Vehicle selectVehicleById(Long id, String entCode)
    {
        getMany(entCode);
        Vehicle vehicle = vehicleMapper.selectVehicleById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return vehicle;
    }

    /**
     * 查询车辆列表
     *
     * @param vehicle 车辆
     * @param entCode
     * @return 车辆
     */
    @Override
    public List<Vehicle> selectVehicleList(Vehicle vehicle, String entCode)
    {
        getMany(entCode);
        List<Vehicle> vehicles = vehicleMapper.selectVehicleList(vehicle);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return vehicles;
    }

    /**
     * 新增车辆
     *
     * @param vehicle 车辆
     * @return 结果
     */
    @Override
    public int insertVehicle(Vehicle vehicle, String entCode)
    {
        getMany(entCode);
        vehicle.setCreateTime(DateUtils.getNowDate());
        String userKey = UUID.randomUUID().toString();
        vehicle.setVin(userKey);
        int i = vehicleMapper.insertVehicle(vehicle);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return i;
    }

    /**
     * 修改车辆
     *
     * @param vehicle 车辆
     * @return 结果
     */
    @Override
    public int updateVehicle(Vehicle vehicle, String entCode)
    {
        getMany(entCode);
        vehicle.setUpdateTime(DateUtils.getNowDate());
        int i = vehicleMapper.updateVehicle(vehicle);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return i;
    }

    /**
     * 批量删除车辆
     *
     * @param ids 需要删除的车辆主键
     * @return 结果
     */
    @Override
    public int deleteVehicleByIds(Long[] ids, String entCode)
    {
        getMany(entCode);
        int i = vehicleMapper.deleteVehicleByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return i;

    }

    /**
     * 删除车辆信息
     *
     * @param id 车辆主键
     * @return 结果
     */
    @Override
    public int deleteVehicleById(Long id, String entCode)
    {
        getMany(entCode);
        int i = vehicleMapper.deleteVehicleById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return i;

    }

    public void getMany(String entCode){
        //切换数据库 切换到从数据库
        DynamicDataSourceHolder.setDynamicDataSourceKey(entCode);
    }
}
